<?php

namespace Mochabear\EasySocialLinks\Includes;

if( ! defined( 'ABSPATH' ) ) die('Not allowed');

class MBESL_Submenu extends MBESL_Base {

	function __construct() {
		parent::__construct();
		add_action( 'admin_menu', array( $this, 'create_submenu') );
		add_action( 'wp_ajax_settings_update', array($this, 'settings_update_callback'));
		add_filter( "plugin_action_link_easy-social-links/easy-social-links.php", array( $this, 'add_plugin_link' ) );
		add_filter( 'plugin_row_meta', array( $this, 'add_donate_link' ), 10, 4 );
	}

	function create_submenu() {
		$hook = add_management_page(
			'Easy Social Links',
			'Social Links',
			'edit_pages',
			'easy-social-links',
			array( $this, 'admin_page' ),
			10
		);
		add_action( "load-$hook", array( $this, 'admin_page_load' ) );
	}


	function admin_page_load() {

	    wp_enqueue_style(
	      'easy-social-links-admin',
	      $this->plugins_url . '/assets/css/admin.css',
	      array(), 
	      true,
	      'all'
	    );

	    wp_enqueue_style(
	      'fork-awesome',
	      $this->plugins_url . '/assets/lib/fork-awesome/css/fork-awesome.min.css',
	      array(), 
	      true,
	      'all'
	    );

		wp_enqueue_script( 'jquery-ui-sortable');

	    wp_register_script(
	      'easy-social-links-admin',
	      $this->plugins_url . '/assets/js/admin.js',
	    );

	    wp_localize_script( 'easy-social-links-admin', 'MBESL', array(
	    	'ajaxurl' => admin_url( 'admin-ajax.php' ),
	    	'security' => wp_create_nonce( 'settings-update-event' ),
	    	'settings' => get_option($this->settings_option)
	    ));

	    wp_enqueue_script( 'easy-social-links-admin' );

    }
 
    function admin_page() {
    	extract(
    		array(
    			"social_media" => $this->social_media,
    			"templates" => $this->templates,
    			"settings" => get_option($this->settings_option),
    		)
    	);
		include 'template-submenu.php';
    }

    public function settings_update_callback() {
		header('Cache-Control: no-cache, must-revalidate');
		header('Expires: '.gmdate('D, d M Y H:i:s \G\M\T', time() + 3600));
		header('Content-type: application/json');

		check_ajax_referer( 'settings-update-event' , 'security' );

		if ( ! isset( $_POST['settings'] ) ) {
			echo "settings is required";
			wp_die();
		}

		update_option(
			$this->settings_option,
			$this->clean_settings_post( $_POST['settings'] )
		);

		$response = new \stdClass();
		$response->status = 200;
		$response->data = get_option($this->settings_option);

		echo json_encode( $response );
		wp_die();
    }

    function clean_settings_post( $settings_post ) {
		$settings = array(
			'generalOptions' => new \stdClass(),
			'socialMediaEnabled' => array(),
			'socialMediaOptions' => array(),
		);

		foreach ($settings_post as $settings_key => $settings_value) {
			$settings_key = sanitize_text_field( $settings_key );

			switch ($settings_key) {
				case "generalOptions":
					foreach ($settings_value as $option_key => $option_value) {
						if ( in_array($option_key, array('openInNewTab') ) )
							$settings['generalOptions']->{ sanitize_text_field( $option_key ) } = sanitize_key( $option_value );
					}	
				break;
				case "socialMediaEnabled":
					foreach ($settings_value as $social_media) {
						if ( isset( $this->social_media[ $social_media ] ) )
							$settings['socialMediaEnabled'][] = sanitize_key( $social_media );
					}
				break;
				case "socialMediaOptions":
					foreach ($settings_value as $social_media => $social_media_properties) {
						if ( isset( $this->social_media[ $social_media ] ) ) {
							$settings['socialMediaOptions'][ sanitize_text_field( $social_media ) ] = array();
							$settings['socialMediaOptions'][ sanitize_text_field( $social_media ) ]['label'] = sanitize_text_field( $social_media_properties['label'] );
							$settings['socialMediaOptions'][ sanitize_text_field( $social_media ) ]['url'] = esc_url_raw( $social_media_properties['url'] );
							$settings['socialMediaOptions'][ sanitize_text_field( $social_media ) ]['order'] = intval( $social_media_properties['order'] );
						}
					}
				break;
				default:
				break;
			}
		}

		return $settings;
    }

	function add_plugin_link( $links ) {
		array_push( $links, '<a href="admin.php?page=easy-social-links">' . __( 'Edit' ) . '</a>' );
		array_push( $links, '<a href="https://www.paypal.com/donate?hosted_button_id=2VTRUM4SX87CA" target="_blank">' . __( 'Donate' ) . '</a>' );

		return $links;
	}

	function add_donate_link( $links, $plugin_file_name, $plugin_data, $status ) {
		if ( strpos( $plugin_file_name, 'easy-social-links.php' ) ) {
			array_push( $links, '<a href="https://www.paypal.com/donate?hosted_button_id=2VTRUM4SX87CA" target="_blank">' . __( 'Donate' ) . '</a>' );
		}
		return $links;
	}

	public function build_social_medias() {

    	$settings = get_option($this->settings_option, false);
    	$active_social_medias = "";
    	$inactive_social_medias = "";

    	if ( $settings != false & (is_array($settings) && isset($settings['socialMediaEnabled'])) ) {
			$order = array();
			foreach ($settings['socialMediaEnabled'] as $social_media) {
				if (!isset($settings['socialMediaOptions'][$social_media]['order']))
					continue;
				$order_value = $settings['socialMediaOptions'][$social_media]['order'];
				$order[$order_value] = $social_media;
			}
			ksort($order);

			foreach ($order as $order => $social_media) {
				$active_social_medias .= $this->get_social_media_html($social_media);
			}
		}

		foreach ($this->social_media as $id => $social) {
			if (isset($settings['socialMediaEnabled']) && in_array($id, $settings['socialMediaEnabled']))
				continue; 
			$inactive_social_medias .= $this->get_social_media_html($id);
		}

		echo <<<EOT
<div class="active-social-medias">
	{$active_social_medias}
</div>
<div class="inactive-social-medias">
	{$inactive_social_medias}
</div>
EOT;

	}

	private function get_social_media_html($social_media) {

    	$settings = get_option($this->settings_option);

    	$social = $this->social_media[$social_media];
		$enabled = isset($settings['socialMediaEnabled']) && in_array($social_media, $settings['socialMediaEnabled']) ? true : false;
		$enabled_css = $enabled ? "active" : "";

		$checked_html = $enabled ? 'checked="checked"' : "";
		$checked_css = $enabled ? "" : "hidden";

		$social_url = isset($settings['socialMediaOptions'][$social_media]['url']) ? esc_url( $settings['socialMediaOptions'][$social_media]['url'] ) : esc_url( $social['url'] );
		$social_label = isset($settings['socialMediaOptions'][$social_media]['label']) ? $settings['socialMediaOptions'][$social_media]['label'] : $social['label'];
		$social_order = isset($settings['socialMediaOptions'][$social_media]['order']) ? intval( $settings['socialMediaOptions'][$social_media]['order'] ) : 999;

		return <<<EOT
<div id="{$social_media}-card" class="sortable sortable-placeholder social-media-card {$enabled_css}">
	<div class="social-media-header">
		<div class="icon-col"><i class="fa fa-{$social['icon']}"></i></div>
		<div class="label-col">{$social['label']}</div>
		<div class="toggle-col">
			<label class="uk-switch" for="{$social_media}">
				<input type="checkbox" id="{$social_media}" name="{$social_media}" {$checked_html}>
				<div class="uk-switch-slider"></div>
			</label>
		</div>
	</div>
	<div class="social-media-content-body">
		<div class="{$social_media}-options social-media-options {$checked_css}">
			<p><label for="{$social_media}-label">Label</label> <input type="text" id="{$social_media}-label"  name="{$social_media}-label" value="{$social_label}" /></p>
			<p><label for="{$social_media}-url">URL</label> <input type="text" id="{$social_media}-url" name="{$social_media}-url" value="{$social_url}" /></p>
			<input type="hidden" id="{$social_media}-order" name="{$social_media}-order" value="{$social_order}" />
		</div>
	</div>
</div>
EOT;

	}

}
